Index
All Classes and Interfaces|All Packages|Constant Field Values
B
- BinaryFileBuffer - Class in com.google.code.externalsorting
-
This is essentially a thin wrapper on top of a BufferedReader...
- BinaryFileBuffer(BufferedReader) - Constructor for class com.google.code.externalsorting.BinaryFileBuffer
-
Constructs a BinaryFileBuffer wrapping the given BufferedReader.
- build() - Method in class com.google.code.externalsorting.csv.CsvSortOptions.Builder
-
Builds the CsvSortOptions instance.
- Builder(Comparator<CSVRecord>, int, long) - Constructor for class com.google.code.externalsorting.csv.CsvSortOptions.Builder
-
Constructs a Builder for CsvSortOptions.
C
- charset(Charset) - Method in class com.google.code.externalsorting.csv.CsvSortOptions.Builder
-
Sets the charset for CSV operations.
- close() - Method in class com.google.code.externalsorting.BinaryFileBuffer
-
Closes the underlying BufferedReader.
- close() - Method in class com.google.code.externalsorting.csv.CSVRecordBuffer
-
Closes the underlying CSVParser.
- close() - Method in interface com.google.code.externalsorting.IOStringStack
-
Closes the underlying resource.
- com.google.code.externalsorting - package com.google.code.externalsorting
- com.google.code.externalsorting.csv - package com.google.code.externalsorting.csv
- CsvExternalSort - Class in com.google.code.externalsorting.csv
-
Utility class for performing external sorting on CSV files.
- CSVRecordBuffer - Class in com.google.code.externalsorting.csv
-
Buffer wrapper for CSVRecord iteration and management.
- CSVRecordBuffer(CSVParser) - Constructor for class com.google.code.externalsorting.csv.CSVRecordBuffer
-
Constructs a CSVRecordBuffer wrapping the given CSVParser.
- CsvSortOptions - Class in com.google.code.externalsorting.csv
-
Parameters for csv sorting
- CsvSortOptions.Builder - Class in com.google.code.externalsorting.csv
-
Builder class for constructing CsvSortOptions with custom parameters.
D
- defaultcomparator - Static variable in class com.google.code.externalsorting.ExternalSort
-
default comparator between strings.
- DEFAULTMAXTEMPFILES - Static variable in class com.google.code.externalsorting.csv.CsvExternalSort
-
Default maximal number of temporary files allowed.
- DEFAULTMAXTEMPFILES - Static variable in class com.google.code.externalsorting.ExternalSort
-
Default maximal number of temporary files allowed.
- distinct(boolean) - Method in class com.google.code.externalsorting.csv.CsvSortOptions.Builder
-
Sets whether to use distinct records.
E
- empty() - Method in class com.google.code.externalsorting.BinaryFileBuffer
-
Checks if the buffer is empty.
- empty() - Method in class com.google.code.externalsorting.csv.CSVRecordBuffer
-
Checks if the buffer is empty.
- empty() - Method in interface com.google.code.externalsorting.IOStringStack
-
Checks if the stack is empty.
- estimateAvailableMemory() - Static method in class com.google.code.externalsorting.csv.CsvExternalSort
-
This method calls the garbage collector and then returns the free memory.
- estimateAvailableMemory() - Static method in class com.google.code.externalsorting.ExternalSort
-
Cette méthode appelle le garbage collector et retourne la mémoire libre.
- estimateBestSizeOfBlocks(long, int, long) - Static method in class com.google.code.externalsorting.csv.CsvExternalSort
-
we divide the file into small blocks.
- estimateBestSizeOfBlocks(long, int, long) - Static method in class com.google.code.externalsorting.ExternalSort
-
Calcule la taille optimale des blocs pour le tri externe.
- estimatedSizeOf(Object) - Static method in class com.google.code.externalsorting.csv.SizeEstimator
-
Estimates the size of a object in bytes.
- estimatedSizeOf(String) - Static method in class com.google.code.externalsorting.StringSizeEstimator
-
Estimates the size of a
Stringobject in bytes. - ExternalSort - Class in com.google.code.externalsorting
-
Goal: offer a generic external-memory sorting program in Java.
- ExternalSort() - Constructor for class com.google.code.externalsorting.ExternalSort
-
Default constructor for ExternalSort.
F
- format(CSVFormat) - Method in class com.google.code.externalsorting.csv.CsvSortOptions.Builder
-
Sets the CSV format.
G
- getCharset() - Method in class com.google.code.externalsorting.csv.CsvSortOptions
-
Gets the charset used for reading/writing CSV files.
- getComparator() - Method in class com.google.code.externalsorting.csv.CsvSortOptions
-
Gets the comparator used for sorting CSV records.
- getFormat() - Method in class com.google.code.externalsorting.csv.CsvSortOptions
-
Gets the CSV format used for parsing and writing.
- getMaxMemory() - Method in class com.google.code.externalsorting.csv.CsvSortOptions
-
Gets the maximum memory to use (in bytes).
- getMaxTmpFiles() - Method in class com.google.code.externalsorting.csv.CsvSortOptions
-
Gets the maximum number of temporary files.
- getNumHeader() - Method in class com.google.code.externalsorting.csv.CsvSortOptions
-
Gets the number of header rows in the input file.
I
- IOStringStack - Interface in com.google.code.externalsorting
-
General interface to abstract away BinaryFileBuffer so that users of the library can roll their own.
- isDistinct() - Method in class com.google.code.externalsorting.csv.CsvSortOptions
-
Indicates whether distinct records should be used.
- isSkipHeader() - Method in class com.google.code.externalsorting.csv.CsvSortOptions
-
Indicates whether the header should be skipped in the output file.
M
- main(String[]) - Static method in class com.google.code.externalsorting.ExternalSort
-
Main entry point for the external sorting program.
- mergeSortedFiles(BufferedWriter, CsvSortOptions, List<CSVRecordBuffer>, List<CSVRecord>) - Static method in class com.google.code.externalsorting.csv.CsvExternalSort
-
Merges multiple sorted CSVRecordBuffer objects into a single output file.
- mergeSortedFiles(BufferedWriter, Comparator<String>, boolean, List<IOStringStack>) - Static method in class com.google.code.externalsorting.ExternalSort
-
This merges several BinaryFileBuffer to an output writer.
- mergeSortedFiles(List<File>, BufferedWriter, Comparator<String>, Charset, boolean, boolean) - Static method in class com.google.code.externalsorting.ExternalSort
-
This merges a bunch of temporary flat files
- mergeSortedFiles(List<File>, File) - Static method in class com.google.code.externalsorting.ExternalSort
-
This merges a bunch of temporary flat files
- mergeSortedFiles(List<File>, File, CsvSortOptions, boolean, List<CSVRecord>) - Static method in class com.google.code.externalsorting.csv.CsvExternalSort
-
Merges multiple sorted CSV files into a single output file.
- mergeSortedFiles(List<File>, File, Comparator<String>) - Static method in class com.google.code.externalsorting.ExternalSort
-
This merges a bunch of temporary flat files
- mergeSortedFiles(List<File>, File, Comparator<String>, boolean) - Static method in class com.google.code.externalsorting.ExternalSort
-
This merges a bunch of temporary flat files
- mergeSortedFiles(List<File>, File, Comparator<String>, Charset) - Static method in class com.google.code.externalsorting.ExternalSort
-
This merges a bunch of temporary flat files
- mergeSortedFiles(List<File>, File, Comparator<String>, Charset, boolean) - Static method in class com.google.code.externalsorting.ExternalSort
-
This merges a bunch of temporary flat files
- mergeSortedFiles(List<File>, File, Comparator<String>, Charset, boolean, boolean, boolean) - Static method in class com.google.code.externalsorting.ExternalSort
-
This merges a bunch of temporary flat files
N
- numHeader(int) - Method in class com.google.code.externalsorting.csv.CsvSortOptions.Builder
-
Sets the number of header rows.
P
- peek() - Method in class com.google.code.externalsorting.BinaryFileBuffer
-
Returns the next line in the buffer without removing it.
- peek() - Method in class com.google.code.externalsorting.csv.CSVRecordBuffer
-
Returns the next CSVRecord in the buffer without removing it.
- peek() - Method in interface com.google.code.externalsorting.IOStringStack
-
Returns the next element without removing it.
- pop() - Method in class com.google.code.externalsorting.BinaryFileBuffer
-
Removes and returns the next line in the buffer.
- pop() - Method in class com.google.code.externalsorting.csv.CSVRecordBuffer
-
Removes and returns the next CSVRecord in the buffer.
- pop() - Method in interface com.google.code.externalsorting.IOStringStack
-
Removes and returns the next element.
S
- SizeEstimator - Class in com.google.code.externalsorting.csv
-
Utility class for estimating the memory size of objects and arrays in the JVM.
- skipHeader(boolean) - Method in class com.google.code.externalsorting.csv.CsvSortOptions.Builder
-
Sets whether to skip the header in output.
- sort(File, File) - Static method in class com.google.code.externalsorting.ExternalSort
-
This sorts a file (input) to an output file (output) using default parameters
- sort(File, File, Comparator<String>) - Static method in class com.google.code.externalsorting.ExternalSort
-
This sorts a file (input) to an output file (output) using customized comparator
- sortAndSave(List<String>, Comparator<String>, Charset, File) - Static method in class com.google.code.externalsorting.ExternalSort
-
Sort a list and save it to a temporary file
- sortAndSave(List<String>, Comparator<String>, Charset, File, boolean, boolean, boolean) - Static method in class com.google.code.externalsorting.ExternalSort
-
Sort a list and save it to a temporary file
- sortAndSave(List<CSVRecord>, File, CsvSortOptions) - Static method in class com.google.code.externalsorting.csv.CsvExternalSort
-
Sorts a list of CSVRecord objects and saves them to a temporary file.
- sortInBatch(long, BufferedReader, File, CsvSortOptions, List<CSVRecord>) - Static method in class com.google.code.externalsorting.csv.CsvExternalSort
-
Sorts records in batches and saves them to temporary files.
- sortInBatch(BufferedReader, long) - Static method in class com.google.code.externalsorting.ExternalSort
-
This will simply load the file by blocks of lines, then sort them in-memory, and write the result to temporary files that have to be merged later.
- sortInBatch(BufferedReader, long, Comparator<String>, boolean) - Static method in class com.google.code.externalsorting.ExternalSort
-
This will simply load the file by blocks of lines, then sort them in-memory, and write the result to temporary files that have to be merged later.
- sortInBatch(BufferedReader, long, Comparator<String>, int, long, Charset, File, boolean, int, boolean, boolean) - Static method in class com.google.code.externalsorting.ExternalSort
-
This will simply load the file by blocks of lines, then sort them in-memory, and write the result to temporary files that have to be merged later.
- sortInBatch(File) - Static method in class com.google.code.externalsorting.ExternalSort
-
This will simply load the file by blocks of lines, then sort them in-memory, and write the result to temporary files that have to be merged later.
- sortInBatch(File, File, CsvSortOptions, List<CSVRecord>) - Static method in class com.google.code.externalsorting.csv.CsvExternalSort
-
Sorts records from a file in batches and saves them to temporary files.
- sortInBatch(File, Comparator<String>) - Static method in class com.google.code.externalsorting.ExternalSort
-
This will simply load the file by blocks of lines, then sort them in-memory, and write the result to temporary files that have to be merged later.
- sortInBatch(File, Comparator<String>, boolean) - Static method in class com.google.code.externalsorting.ExternalSort
-
This will simply load the file by blocks of lines, then sort them in-memory, and write the result to temporary files that have to be merged later.
- sortInBatch(File, Comparator<String>, int, Charset, File, boolean) - Static method in class com.google.code.externalsorting.ExternalSort
-
This will simply load the file by blocks of lines, then sort them in-memory, and write the result to temporary files that have to be merged later.
- sortInBatch(File, Comparator<String>, int, Charset, File, boolean, int) - Static method in class com.google.code.externalsorting.ExternalSort
-
This will simply load the file by blocks of lines, then sort them in-memory, and write the result to temporary files that have to be merged later.
- sortInBatch(File, Comparator<String>, int, Charset, File, boolean, int, boolean) - Static method in class com.google.code.externalsorting.ExternalSort
-
This will simply load the file by blocks of lines, then sort them in-memory, and write the result to temporary files that have to be merged later.
- sortInBatch(File, Comparator<String>, int, Charset, File, boolean, int, boolean, boolean) - Static method in class com.google.code.externalsorting.ExternalSort
-
This will simply load the file by blocks of lines, then sort them in-memory, and write the result to temporary files that have to be merged later.
- sortInBatch(File, Comparator<String>, File, boolean, int) - Static method in class com.google.code.externalsorting.ExternalSort
-
This will simply load the file by blocks of lines, then sort them in-memory, and write the result to temporary files that have to be merged later.
- sortInBatch(File, Comparator<String>, Charset, File, boolean, int) - Static method in class com.google.code.externalsorting.ExternalSort
-
This will simply load the file by blocks of lines, then sort them in-memory, and write the result to temporary files that have to be merged later.
- StringSizeEstimator - Class in com.google.code.externalsorting
-
Simple class used to estimate memory usage.
All Classes and Interfaces|All Packages|Constant Field Values